@@ -22,7 +22,7 @@
 
 #include "DeviceList_p.h"
 
-#include <parser.h>
+#include "qjsonwrapper/Json.h"
 
 using namespace mygpo;
 
@@ -34,7 +34,6 @@ DeviceListPrivate::DeviceListPrivate( DeviceList* qq, QNetworkReply* reply ) : q
 
 DeviceListPrivate::~DeviceListPrivate()
 {
-    delete m_reply;
 }
 
 QVariant DeviceListPrivate::devices() const
@@ -74,9 +73,8 @@ bool DeviceListPrivate::parse( const QVariant& data )
 
 bool DeviceListPrivate::parse( const QByteArray& data )
 {
-    QJson::Parser parser;
     bool ok;
-    QVariant variant = parser.parse( data, &ok );
+    QVariant variant = QJsonWrapper::parseJson( data, &ok );
     if( ok )
     {
         ok = ( parse( variant ) );
@@ -98,6 +96,7 @@ void DeviceListPrivate::parseData()
             emit q->parseError();
         }
     }
+    m_reply->deleteLater();
 }
 
 DeviceList::DeviceList( QNetworkReply* reply, QObject* parent ) : QObject( parent ), d( new DeviceListPrivate( this, reply ) )
