@@ -22,7 +22,7 @@
 
 #include "Episode_p.h"
 
-#include <parser.h>
+#include "qjsonwrapper/Json.h"
 
 using namespace mygpo;
 
@@ -115,9 +115,8 @@ bool EpisodePrivate::parse ( const QVariant& data )
 
 bool EpisodePrivate::parse ( const QByteArray& data )
 {
-    QJson::Parser parser;
     bool ok;
-    QVariant variant = parser.parse ( data, &ok );
+    QVariant variant = QJsonWrapper::parseJson( data, &ok );
     if ( ok )
     {
         if ( !parse ( variant ) ) return false;
