@@ -22,7 +22,7 @@
 
 #include "EpisodeAction_p.h"
 
-#include <parser.h>
+#include "qjsonwrapper/Json.h"
 
 using namespace mygpo;
 
@@ -163,9 +163,8 @@ bool EpisodeActionPrivate::parseActionType( const QString& data )
 
 bool EpisodeActionPrivate::parse( const QByteArray& data )
 {
-    QJson::Parser parser;
     bool ok;
-    QVariant variant = parser.parse( data, &ok );
+    QVariant variant = QJsonWrapper::parseJson( data, &ok );
     if( ok )
     {
         if( !parse( variant ) ) return false;
