@@ -1,6 +1,6 @@
 /***************************************************************************
 * This file is part of libmygpo-qt                                         *
-* Copyright (c) 2010 - 2011 Stefan Derkits <stefan@derkits.at>             *
+* Copyright (c) 2010 - 2013 Stefan Derkits <stefan@derkits.at>             *
 * Copyright (c) 2010 - 2011 Christian Wagner <christian.wagner86@gmx.at>   *
 * Copyright (c) 2010 - 2011 Felix Winter <ixos01@gmail.com>                *
 *                                                                          *
@@ -20,8 +20,8 @@
 * USA                                                                      *
 ***************************************************************************/
 
-#ifndef REQUESTHANDLER_H_
-#define REQUESTHANDLER_H_
+#ifndef LIBMYGPO_QT_REQUESTHANDLER_H_
+#define LIBMYGPO_QT_REQUESTHANDLER_H_
 
 #include "mygpo_export.h"
 
@@ -77,9 +77,10 @@ private:
     QString m_password;
     QNetworkAccessManager* m_nam;
 
-    void addAuthData( QNetworkRequest& url );
+    void addAuthData( QNetworkRequest& request );
+    void addUserAgent( QNetworkRequest& request );
 };
 
 }
 
-#endif /* REQUESTHANDLER_H_ */
+#endif /* LIBMYGPO_QT_REQUESTHANDLER_H_ */
